==> r2r-3.3.40-py3-none-any.whl: core/providers/__init__.py <==
from .auth import JwtAuthProvider, R2RAuthProvider, SupabaseAuthProvider
from .crypto import (
    BcryptCryptoConfig,
    BCryptCryptoProvider,
    NaClCryptoConfig,
    NaClCryptoProvider,
)
from .database import PostgresDatabaseProvider
from .email import (
    AsyncSMTPEmailProvider,
    ConsoleMockEmailProvider,
    SendGridEmailProvider,
)
from .embeddings import (
    LiteLLMEmbeddingProvider,
    OllamaEmbeddingProvider,
    OpenAIEmbeddingProvider,
)
from .ingestion import (  # type: ignore
    R2RIngestionConfig,
    R2RIngestionProvider,
    UnstructuredIngestionConfig,
    UnstructuredIngestionProvider,
)
from .llm import (
    AnthropicCompletionProvider,
    LiteLLMCompletionProvider,
    OpenAICompletionProvider,
    R2RCompletionProvider,
)
from .orchestration import (
    HatchetOrchestrationProvider,
    SimpleOrchestrationProvider,
)

__all__ = [
    # Auth
    "R2RAuthProvider",
    "SupabaseAuthProvider",
    "JwtAuthProvider",
    # Ingestion
    "R2RIngestionProvider",
    "R2RIngestionConfig",
    "UnstructuredIngestionProvider",
    "UnstructuredIngestionConfig",
    # Crypto
    "BCryptCryptoProvider",
    "BcryptCryptoConfig",
    "NaClCryptoConfig",
    "NaClCryptoProvider",
    # Embeddings
    "LiteLLMEmbeddingProvider",
    "OllamaEmbeddingProvider",
    "OpenAIEmbeddingProvider",
    # Database
    "PostgresDatabaseProvider",
    # Email
    "AsyncSMTPEmailProvider",
    "ConsoleMockEmailProvider",
    "SendGridEmailProvider",
    # Orchestration
    "HatchetOrchestrationProvider",
    "SimpleOrchestrationProvider",
    # LLM
    "AnthropicCompletionProvider",
    "OpenAICompletionProvider",
    "R2RCompletionProvider",
    "LiteLLMCompletionProvider",
]

==> r2r-3.5.6-py3-none-any.whl: core/providers/__init__.py <==
from .auth import (
    ClerkAuthProvider,
    JwtAuthProvider,
    R2RAuthProvider,
    SupabaseAuthProvider,
)
from .crypto import (
    BcryptCryptoConfig,
    BCryptCryptoProvider,
    NaClCryptoConfig,
    NaClCryptoProvider,
)
from .database import PostgresDatabaseProvider
from .email import (
    AsyncSMTPEmailProvider,
    ConsoleMockEmailProvider,
    MailerSendEmailProvider,
    SendGridEmailProvider,
)
from .embeddings import (
    LiteLLMEmbeddingProvider,
    OllamaEmbeddingProvider,
    OpenAIEmbeddingProvider,
)
from .ingestion import (  # type: ignore
    R2RIngestionConfig,
    R2RIngestionProvider,
    UnstructuredIngestionConfig,
    UnstructuredIngestionProvider,
)
from .llm import (
    AnthropicCompletionProvider,
    LiteLLMCompletionProvider,
    OpenAICompletionProvider,
    R2RCompletionProvider,
)
from .orchestration import (
    HatchetOrchestrationProvider,
    SimpleOrchestrationProvider,
)
from .scheduler import (
    APSchedulerProvider,
)

__all__ = [
    # Auth
    "R2RAuthProvider",
    "SupabaseAuthProvider",
    "JwtAuthProvider",
    "ClerkAuthProvider",
    # Ingestion
    "R2RIngestionProvider",
    "R2RIngestionConfig",
    "UnstructuredIngestionProvider",
    "UnstructuredIngestionConfig",
    # Crypto
    "BCryptCryptoProvider",
    "BcryptCryptoConfig",
    "NaClCryptoConfig",
    "NaClCryptoProvider",
    # Embeddings
    "LiteLLMEmbeddingProvider",
    "OllamaEmbeddingProvider",
    "OpenAIEmbeddingProvider",
    # Database
    "PostgresDatabaseProvider",
    # Email
    "AsyncSMTPEmailProvider",
    "ConsoleMockEmailProvider",
    "SendGridEmailProvider",
    "MailerSendEmailProvider",
    # LLM
    "AnthropicCompletionProvider",
    "OpenAICompletionProvider",
    "R2RCompletionProvider",
    "LiteLLMCompletionProvider",
    # Orchestration
    "HatchetOrchestrationProvider",
    "SimpleOrchestrationProvider",
    # Scheduler
    "APSchedulerProvider",
]
